Learn R Programming

releaser (version 1.2.1)

check: Check for missing or deprecated documentation tag

Description

check_missing_examples_tag() Identifies exported functions that do not declare any @examples (or @examplesIf) tag in their roxygen2 documentation. check_missing_examples_content() detects exported functions that declare an @examples tag but whose examples are not actually present in the combined example blocks. check_missing_title() identifies exported functions that do not define a @title tag in their documentation. check_describeIn_usage() lists all documented topics using the @describeIn tag. check_return_tag_usage() identifies functions still using @return. check_missing_returns() identifies exported functions that do not declare a @returns tag.

Usage

check_missing_examples_tag(pkg_dir)

check_missing_examples_content(pkg_dir)

check_missing_title(pkg_dir)

check_describeIn_usage(pkg_dir)

check_return_tag_usage(pkg_dir)

check_missing_returns(pkg_dir)

Value

A character vector of function names

Arguments

pkg_dir

Path to the R package.

Details

The @describeIn tag is generally discouraged in modern roxygen2 workflows. The @return tag is superseded by @returns.

Examples

Run this code
if (FALSE) {
my_pkg_dir <- "path/to/my/package"

# Single checks
check_missing_returns(my_pkg_dir)
check_return_tag_usage(my_pkg_dir)
check_describeIn_usage(my_pkg_dir)
check_missing_examples_tag(my_pkg_dir)
check_missing_examples_content(my_pkg_dir)
check_missing_title(my_pkg_dir)
}

Run the code above in your browser using DataLab